Crate diesel_autoincrement_new_struct
diesel_
autoincrement_
new_
struct
0.1.1
All Items
Crate Items
Modules
Macros
Attribute Macros
Crate
diesel_
autoincrement_
new_
struct
Modules

prelude
Macros

NewInsertable
Macro to generate a New struct for Diesel insertions without an ‘id’ field
diesel_
new
Macro to generate a New struct for Diesel insertions without an ‘id’ field
paste
Attribute Macros

apply
derive